#
# spec file for package atinject
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global artifactversion 1.0.5
Name:           atinject
Version:        1+20211017gitd06ce18
Release:        1.3
Summary:        Dependency injection specification for Java (JSR-330)
License:        Apache-2.0
URL:            https://github.com/jakartaee/inject/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
Obsoletes:      %{name}-tck
BuildArch:      noarch

%description
This package specifies a means for obtaining objects in such a way as
to maximize reusability, testability and maintainability compared to
traditional approaches such as constructors, factories, and service
locators (e.g., JNDI). This process, known as dependency injection, is
beneficial to most nontrivial applications.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
%{ant} package javadoc

%install
# jars
install -dm 755 %{buildroot}%{_javadir}/javax.inject
install -m 0644 target/javax.inject-%{artifactversion}.jar %{buildroot}%{_javadir}/%{name}.jar
(cd %{buildroot}%{_javadir}/javax.inject && ln -s ../%{name}.jar .)
%add_maven_depmap javax.inject:javax.inject:%{artifactversion} %{name}.jar

# javadoc
install -dm 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt NOTICE.md
%{_javadir}/javax.inject

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Tue Jul  9 2024 Fridrich Strba <fstrba@suse.com>
- Revert to versioning 1+<date>git<git short hash> to avoid upgrade
  problems in SLE
* Fri Jun  7 2024 Fridrich Strba <fstrba@suse.com>
- Don't distribute as jakarta.inject:jakarta-inject-api artifact
  to prevent conflicts with the version 2.x that actually has
  classes in jakarta.inject namespace and thus is incompatible
* Wed Apr 10 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.0.5 and switch to sources in
  https://github.com/jakartaee/inject/
  * Changes of 1.0.5:
    + This switches the module name back to the java.inject that was
    used by the 1.0.3 release with automatic module. This is a
    multi-release jar
  * Changes of 1.0.4:
    + This is a 1.0.4 service release with a multi-release jar that
    adds the module-info class to
    META-INF/versions/9/module-info.class using the
    https://github.com/moditect/moditect plugin for the
    javax.inject module.
  * Changes of 1.0.3:
    + This release corrects the 1.0.2 release which was incorrectly
    done from the master branch with the jakarta.* packages.
    + It adds the Automatic-Module-Name=java.inject to the api jar
    manifest.
  * Changes of 1.0.2:
    + A service release that addresses:
  - #14, set Automatic-Module-Name to java.inject
  - #15, add OSGi bundle headers
  * Changes of 1.0.1:
    + Add Automatic-Module-Name of jakarta.inject
  * Changes of 1.0:
    + First Injection API release for Jakarta EE
- Remove unused sub-package tck
- Removed patch:
  * atinject-javadoc.patch
    + not needed with this version
* Sat Apr  2 2022 Fridrich Strba <fstrba@suse.com>
- Alias to the new jakarta name
* Thu Mar 24 2022 Fridrich Strba <fstrba@suse.com>
- Fetch the sources using a source service
- Do not use the upstream build.sh, but use it to write a
  necessary part directly to the spec file
* Sat Mar 19 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
- Added patch:
  * atinject-javadoc.patch
    + fix build with javadoc 17
* Wed Oct 24 2018 Fridrich Strba <fstrba@suse.com>
- Initial packaging of atinject adapted from Fedora rpm
